#
# Copyright (c) 2001-2003 The Trustees of Indiana University.  
#                         All rights reserved.
# Copyright (c) 1998-2001 University of Notre Dame. 
#                         All rights reserved.
# Copyright (c) 1994-1998 The Ohio State University.  
#                         All rights reserved.
# 
# This file is part of the LAM/MPI software package.  For license
# information, see the LICENSE file in the top level directory of the
# LAM/MPI source distribution.
# 
# $Id: lam-generic.spec,v 1.3.2.3 2003/09/24 11:00:33 jsquyres Exp $
#

#############################################################################
#
# Helpful defines
#
#############################################################################

%define _sysconfdir /etc/lam
%define _romiodocdir /usr/share/lam/doc


#############################################################################
#
# Preamble Section
#
#############################################################################

Summary: LAM/MPI (Local Area Multicomputer) programming environment
Name: lam
Version: 7.0.6
Release: 2ak6
Vendor: LAM/MPI Team
License: BSD
Group: Development/Libraries
Source: lam-%{version}.tar.gz
URL: http://www.lam-mpi.org/
BuildRoot: %{_tmppath}/%{name}-%{version}-root
Epoch: 2
Provides: mpi
Requires: gcc
Requires: gcc-c++
Requires: gcc-g77

%description 
LAM (Local Area Multicomputer) is an MPI programming environment and
development system for heterogeneous computers on a network. With
LAM/MPI, a dedicated cluster or an existing network computing
infrastructure can act as a single parallel computer.  LAM/MPI is
considered to be "cluster friendly", in that it offers daemon-based
process startup/control as well as fast client-to-client message
passing protocols.  LAM/MPI can use TCP/IP and/or shared memory for
message passing (currently, different RPMs are supplied for this --
see the main LAM web site for details).

LAM features a full implementation of MPI-1 (with the exception that
LAM does not support cancelling of sends), and much of MPI-2.
Compliant applications are source code portable between LAM/MPI and
any other implementation of MPI.  In addition to providing a
high-quality implementation of the MPI standard, LAM/MPI offers
extensive monitoring capabilities to support debugging.  Monitoring
happens on two levels.  First, LAM/MPI has the hooks to allow a
snapshot of process and message status to be taken at any time during
an application run.  This snapshot includes all aspects of
synchronization plus datatype maps/signatures, communicator group
membership, and message contents (see the XMPI application on the main
LAM web site).  On the second level, the MPI library is instrumented
to produce a cummulative record of communication, which can be
visualized either at runtime or post-mortem.


#############################################################################
#
# Prep Section
#
#############################################################################
%prep
%setup -q

# Otherwise, this directory shows up on security reports
chmod -R o-w $RPM_BUILD_DIR/lam-%{version}

#############################################################################
#
# Build Section
#
#############################################################################
%build
F77='g77'
CC='gcc'
CXX='g++'
FC=${F77}
FFLAGS=${FFLAGS-}
CONFEXTRA="--without-threads"
%ifarch i386 i486 i586 i686 athlon x86_64
FFLAGS="${FFLAGS} -fno-second-underscore"
%endif
%ifarch x86_64
F77='g77 -m64'
CC='gcc -m64'
CXX='g++ -m64'
FC=${F77}
CONFEXTRA="${CONFEXTRA} --disable-tv"
%endif
export F77 FC FFLAGS CONFEXTRA

%configure --with-rpi=usysv --with-fc="${F77}" ${CONFEXTRA}
make all

#############################################################################
#
# Install Section
#
#############################################################################
%install
rm -rf $RPM_BUILD_ROOT
%makeinstall

rm -f $RPM_BUILD_ROOT%{_includedir}/mpi++.h
ln -s mpi2c++/mpi++.h $RPM_BUILD_ROOT%{_includedir}/mpi++.h

# Rename the ROMIO doc files so that we can install them in the same
# doc root later, and not overwrite LAM's doc files.

for file in README README_LAM COPYRIGHT; do
	mv $RPM_BUILD_DIR/lam-%{version}/romio/$file \
		$RPM_BUILD_DIR/lam-%{version}/romio/romio-$file
done
mv $RPM_BUILD_DIR/lam-%{version}/romio/doc/users-guide.ps.gz \
	$RPM_BUILD_DIR/lam-%{version}/romio/doc/romio-users-guide.ps.gz

rm -rvf $RPM_BUILD_ROOT/usr/share/lam/doc

#################
# build a couple of wrapper scripts that
# will call the respective non-GNU compilers
# the the lam libraries.
#################
# helper function to build the wrapper scripts.
mkmpiwrap () {
cat > $RPM_BUILD_ROOT%{_bindir}/mpi$1 <<EOF
#!/bin/sh
# lam-mpi $1 wrapper script.
# (c) 2003 by axel.kohlmeyer@theochem.ruhr-uni-bochum.de
# see http://www.theochem.ruhr-uni-bochum.de/~axel.kohlmeyer/cpmd-linux.html
# for more info.

$2=$1
export $2
exec %{_bindir}/mpi$3 "\$@"
EOF

chmod 755 $RPM_BUILD_ROOT%{_bindir}/mpi$1
}

# build wrappers for the portland group compilers.
%ifarch i386 i486 i586 i686 athlon x86_64
mkmpiwrap pgf77 LAMHF77 f77
mkmpiwrap pgf90 LAMHF77 f77
mkmpiwrap pghpf LAMHF77 f77
mkmpiwrap pgcc  LAMHCC  cc
mkmpiwrap pgCC  LAMHCP  CC
%endif 

# build wrappers for the intel compilers (not available on x86_64 :-))
%ifarch i386 i486 i586 i686 athlon
mkmpiwrap ifort LAMHF77 f77
mkmpiwrap ifc   LAMHF77 f77
mkmpiwrap icc   LAMHCC  cc
mkmpiwrap icpc  LAMHCP  CC
%endif

%ifarch alpha
# build wrappers for the compaq alpha linux compilers
mkmpiwrap fort LAMHF77 f77
mkmpiwrap ccc  LAMHCC  cc
mkmpiwrap cxx  LAMHCP  CC
%endif

#############################################################################
#
# Clean Section
#
#############################################################################
%clean
rm -rf $RPM_BUILD_ROOT

#############################################################################
#
# Files Section
#
#############################################################################
%files
%defattr(-,root,root)
%doc LICENSE HISTORY INSTALL README
%doc examples
%doc doc/*.pdf
# Need to fix ROMIO install script to install its docs in the Right place
%doc romio/doc/romio-users-guide.ps.gz romio/romio-*
%config %{_sysconfdir}
%{_bindir}/*
%{_mandir}/*/*
%{_includedir}/*
%{_libdir}/*
%{_datadir}/lam/*

#############################################################################
#
# Changelog
#
#############################################################################
%changelog
* Wed Nov 19 2003 Axel Kohlmeyer <axel.kohlmeyer@nexgo.de>
- added more wrappers to support also the respective c/c++ compilers
- disabled (internal) threads support as it collides with the multi-compiler 
  wrapper scripts.
- added a helper function make the wrapper script generation more error proof.
- added opteron (i.e. x86_64) support for pgi compilers

* Wed Sep 24 2003 Jeff Squyres <jsquyres@lam-mpi.org>
- Added explicit requires for gcc, gcc-c++, and gcc-g77.

* Tue Aug 26 2003 Axel Kohlmeyer <axel.kohlmeyer@theochem.ruhr-uni-bochum.de>
- added options to build on alpha linux:
 + added wrapper scripts mpifort for compaq alpha.
 + naming convention of fort are the same as g77 (so set -fno-second-underscore
   only on x86 archs)

* Mon Aug 11 2003 Axel Kohlmeyer <axel.kohlmeyer@theochem.ruhr-uni-bochum.de>
- modified the spec file so that we get an non-g77 compiler compatible rpm.
  in detail:
   + fortran compiler is set to g77 -fno-second-underscore to have
     pgi and ifc compatible naming conventions
   + added wrapper scripts mpipgf77, mpipgf90, mpiifc to call the respective
     compilers transparently

* Mon May 29 2003 Jeff Squyres <jsquyres@lam-mpi.org>
- Updated for LAM/MPI 7.0; added doc/*.pdf; removed some other
  (outdated) %doc files
- Ensure extracted LAM source directory is not world-writeable;
  otherwise it shows up in nightly security reports
- Fixed references to get ROMIO docs

* Mon Nov 26 2001 Brian William Barrett <brbarret@lam-mpi.org>
- Fixed typo - C++ header file symlink was mpi++ instead of mpi++.h

* Wed Oct 31 2001 Jeff Squyres <jsquyres@lam-mpi.org>
- Changed license to be BSD.

* Thu Jul 05 2001 Jeff Squyres <jsquyres@lam-mpi.org>
- Modified slightly to be similar to the OSCAR spec file.
- Removed use of hard-coded dirs, and replaced them with variables
  instead.
- Removed redundant "cp" statements in install section; automake
  takes care of installing man pages, and there is no $prefix/doc
  anymore.
- Fixed to get the copyright properly.
- Changed "Copyright" to "License" to be a bit more accurate.
- Use "makeinstall" macro in install section instead of "make
  DESTDIR=... install"
- Acknowledge that because we build the LAM RPMs on RH 6.2 machines,
  the man pages and doc files will be in the "wrong" place on RH 7.x
  machines.  There is not much that we can do about this -- we build
  the RPMs on 6.2 machines so that the binaries work on both 6.2 and
  7.x machines (someday we won't care about about 6.2 machines
  anymore, but for the moment, we still do).  The default location for
  man pages and doc files changed in RH 7.x (6.x:/usr/doc/lam-version,
  7.x:/usr/share/lam-version, and 6.x:/usr/man, 7.x:/usr/share/man).
  By not overriding _mandir and _docdir in this .spec file, we're
  allowing for the possibility of rebuilding the source RPM on a 7.x
  machine and getting the doc files/man pages in the right location.
  Even more compelling, however, is the fact that RH 7.x machines will
  still find the man pages, even if they are in the "wrong" (i.e.,
  old) location -- the location that this 6.2-built RPM will place
  them in.

* Mon Mar 17 2001 Brian William Barrett <bbarrett@lam-mpi.org>
- Borrowed SPEC file from Trond at RedHat.  Converted to be able to 
  make RPMs for all RPIs
